import * as react from 'react';

declare const classes: {
    base: string;
    size: {
        sm: string;
        DEFAULT: string;
        lg: string;
        xl: string;
    };
    rounded: {
        none: string;
        sm: string;
        DEFAULT: string;
        lg: string;
        pill: string;
    };
    variant: {
        solid: {
            base: string;
            color: {
                DEFAULT: string;
                primary: string;
                secondary: string;
                danger: string;
                info: string;
                success: string;
                warning: string;
            };
        };
        flat: {
            base: string;
            color: {
                DEFAULT: string;
                primary: string;
                secondary: string;
                danger: string;
                info: string;
                success: string;
                warning: string;
            };
        };
        outline: {
            base: string;
            color: {
                DEFAULT: string;
                primary: string;
                secondary: string;
                danger: string;
                info: string;
                success: string;
                warning: string;
            };
        };
        text: {
            base: string;
            color: {
                DEFAULT: string;
                primary: string;
                secondary: string;
                danger: string;
                info: string;
                success: string;
                warning: string;
            };
        };
    };
};
interface ButtonProps extends React.ButtonHTMLAttributes<HTMLButtonElement> {
    /** Set the loading status of button */
    isLoading?: boolean;
    /** Set the original html type of button */
    type?: 'button' | 'submit' | 'reset';
    /** The variants of the component are: */
    variant?: keyof typeof classes.variant;
    /** The size of the component. `"sm"` is equivalent to the dense button styling. */
    size?: keyof typeof classes.size;
    /** The rounded variants are: */
    rounded?: keyof typeof classes.rounded;
    /** Change button color */
    color?: keyof typeof classes.variant['solid']['color'];
    /** Add custom classes for extra style */
    className?: string;
}
/**
 * Primary action button to trigger an operation. Here is the API documentation of the Button component.
 * And the rest of the props of Button are the same as the original html button.
 * You can use props like `id`, `title`, `onClick`, `onFocus`, `onBlur`, `children` etc.
 */
declare const Button: react.ForwardRefExoticComponent<ButtonProps & react.RefAttributes<HTMLButtonElement>>;

export { Button, ButtonProps };
